@@ -18,11 +18,18 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
+#ifdef HAVE_MATH_H
 #include <math.h>
+#endif
 #include <glib.h>
 #include <string.h>
 
+#define DEGREE_SYMBOL "\302\260"
+
 /**
  * @param pos_c char for positive value
  * @param neg_c char for negative value
@@ -44,8 +51,7 @@ static gchar *convert_dec_to_ddd(gdouble dec, gchar pos_c, gchar neg_c)
   val_d = fabs(dec);
 
   /* Format */
-  /* TODO : replace "" as UTF-8 */
-  result = g_strdup_printf ( "%c%f", sign_c, val_d );
+  result = g_strdup_printf ( "%c%f" DEGREE_SYMBOL, sign_c, val_d );
   return result;
 }
 
@@ -86,8 +92,7 @@ static gchar *convert_dec_to_dmm(gdouble dec, gchar pos_c, gchar neg_c)
   val_m = (tmp - val_d) * 60;
 
   /* Format */
-  /* TODO : replace "" as UTF-8 */
-  result = g_strdup_printf ( "%c%d%f'",
+  result = g_strdup_printf ( "%c%d" DEGREE_SYMBOL "%f'",
                              sign_c, val_d, val_m );
   return result;
 }
@@ -133,8 +138,7 @@ static gchar *convert_dec_to_dms(gdouble dec, gchar pos_c, gchar neg_c)
   val_s = (tmp - val_m) * 60;
 
   /* Format */
-  /* TODO : replace "" as UTF-8 */
-  result = g_strdup_printf ( "%c%d%d'%f\"",
+  result = g_strdup_printf ( "%c%d" DEGREE_SYMBOL "%d'%f\"",
                              sign_c, val_d, val_m, val_s );
   return result;
 }
