@@ -31,12 +31,13 @@
 #include <glib/gi18n.h>
 
 #include "viking.h"
+#include "util.h"
 #include "curl_download.h"
 
 #define GOOGLE_SEARCH_URL_FMT "http://maps.google.com/maps?q=%s&output=js"
 #define GOOGLE_SEARCH_PATTERN_1 "{center:{lat:"
 #define GOOGLE_SEARCH_PATTERN_2 ",lng:"
-#define GOOGLE_SEARCH_NOT_FOUND "around this map area did not match any locations"
+#define GOOGLE_SEARCH_NOT_FOUND "not understand the location"
 
 static gchar *last_search_str = NULL;
 static VikCoord *last_coord = NULL;
@@ -179,26 +180,6 @@ done:
 
 }
 
-gchar *uri_escape(gchar *str)
-{
-  gchar *esc_str = g_malloc(3*strlen(str));
-  gchar *dst = esc_str;
-  gchar *src;
-
-  for (src = str; *src; src++) {
-    if (*src == ' ')
-     *dst++ = '+';
-    else if (g_ascii_isalnum(*src))
-     *dst++ = *src;
-    else {
-      g_sprintf(dst, "%%%02X", *src);
-      dst += 3;
-    }
-  }
-
-    return(esc_str);
-}
-
 static int google_search_get_coord(VikWindow *vw, VikViewport *vvp, gchar *srch_str, VikCoord *coord)
 {
   FILE *tmp_file;
@@ -209,8 +190,12 @@ static int google_search_get_coord(VikWindow *vw, VikViewport *vvp, gchar *srch_
   int ret = 0;  /* OK */
   struct LatLon ll;
 
+  g_debug("%s: raw search: %s", __FUNCTION__, srch_str);
+
   escaped_srch_str = uri_escape(srch_str);
 
+  g_debug("%s: escaped search: %s", __FUNCTION__, escaped_srch_str);
+
   if ((tmp_fd = g_file_open_tmp ("vikgsearch.XXXXXX", &tmpname, NULL)) == -1) {
     g_critical(_("couldn't open temp file"));
     exit(1);
