@@ -18,12 +18,20 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
+#ifdef HAVE_MATH_H
 #include <math.h>
+#endif
+
 #include "viking.h"
 
 #include <ctype.h>
+#ifdef HAVE_STRING_H
 #include <string.h>
+#endif
 
 #include <stdlib.h>
 /* strtod */
