@@ -41,14 +41,10 @@ static const char *menu_xml =
 	"      <menuitem action='ModeUTM'/>"
 #ifdef VIK_CONFIG_EXPEDIA
 	"      <menuitem action='ModeExpedia'/>"
-#endif
-#ifdef VIK_CONFIG_OLD_GOOGLE
-	"      <menuitem action='ModeGoogle'/>"
-	"      <menuitem action='ModeKH'/>"
 #endif
 	"      <menuitem action='ModeMercator'/>"
 	"      <separator/>"
-	"      <menuitem action='GoogleMapsSearch'/>"
+	"      <menuitem action='GotoSearch'/>"
 	"      <menuitem action='GotoLL'/>"
 	"      <menuitem action='GotoUTM'/>"
 	"      <separator/>"
@@ -56,6 +52,7 @@ static const char *menu_xml =
 	"      <menuitem action='ShowCenterMark'/>"
 	"      <menuitem action='SetBGColor'/>"
 	"      <menuitem action='FullScreen'/>"
+	"      <menuitem action='ViewSidePanel'/>"
 	"      <separator/>"
 	"      <menuitem action='ZoomIn'/>"
 	"      <menuitem action='ZoomOut'/>"
@@ -86,6 +83,7 @@ static const char *menu_xml =
 	"      <separator/>"
 	"    </menu>"
 	"    <menu action='Tools'>"
+	"      <menu action='Exttools'/>"
 	"      <menuitem action='Pan'/>"
 	"      <menuitem action='Zoom'/>"
 	"      <menuitem action='Ruler'/>"
@@ -105,15 +103,13 @@ static const char *menu_xml =
 	"      <toolitem name='Exit' action='Exit'/>"
 	"      <separator/>"
 	"    </placeholder>"
-	"    <placeholder name='EditToolItems'>"
-	"      <toolitem name='Cut' action='Cut'/>"
-	"      <toolitem name='Copy' action='Copy'/>"
-	"      <toolitem name='Paste' action='Paste'/>"
-	"      <toolitem name='Delete' action='Delete'/>"
+	"    <placeholder name='UIToolItems'>"
+	"      <toolitem action='FullScreen'/>"
+	"      <toolitem action='ViewSidePanel'/>"
 	"      <separator/>"
 	"    </placeholder>"
 	"    <placeholder name='ViewToolItems'>"
-	"      <toolitem action='GoogleMapsSearch'/>"
+	"      <toolitem action='GotoSearch'/>"
 	"      <separator/>"
 	"    </placeholder>"
 	"    <placeholder name='ToolItems'>"
